icons: Tabler Icons Data

iconsR Documentation

Tabler Icons Data

Description

A dataset containing Tabler icon names and their categories.

Usage

icons

Format

A data frame with 6,019 rows and 3 variables:

root

The root category of the icon (e.g., "arrow/arrows", "brand", "device", etc.)

icon

The full icon name (e.g., "arrow-up", "arrow-down", "circle-arrow-up", "circle-arrow-up-filled", etc.)

filled

Logical indicating whether the icon is a filled or not.

Derived from the icons from https://github.com/tabler/tabler-icons

Examples

icons[grepl("paw", icons$icon), ]

tabler documentation built on Nov. 5, 2025, 6:05 p.m.