menu_dropdown: Create a Dropdown Menu Item

View source: R/core.R

menu_dropdownR Documentation

Description

Create a nav-item with a dropdown menu using columns like the example

Usage

menu_dropdown(text, icon = NULL, href = NULL, items = list())

Arguments

text

Title of the dropdown

icon

Icon name (optional)

href

Link for the dropdown toggle (optional)

items

A list of character vectors or tags representing dropdown links; each element can be a character vector of length 2: c(text, href)

Value

An HTML tag representing the dropdown nav item


tabler documentation built on Nov. 5, 2025, 6:05 p.m.