tabler-package: tabler: Create Dashboards with 'Tabler' and 'Shiny'

tabler-packageR Documentation

tabler: Create Dashboards with 'Tabler' and 'Shiny'

Description

Provides functions to build interactive dashboards combining the 'Tabler UI Kit' with 'Shiny', making it easy to create professional-looking web applications. 'Tabler' is fully responsive and compatible with all modern browsers. Offers customizable layouts and components built with 'HTML5' and 'CSS3'. The underlying 'Tabler' (https://github.com/tabler/tabler) and 'Tabler Icons' (https://github.com/tabler/tabler-icons) were pre-built from source to eliminate the need for 'Node.js' and 'NPM' on package installation.

Author(s)

Maintainer: Mauricio Vargas Sepulveda m.vargas.sepulveda@gmail.com

Other contributors:

  • Tabler (Tabler Dashboard) [contributor, copyright holder]

See Also

Useful links:


tabler documentation built on Nov. 5, 2025, 6:05 p.m.