| icons | R Documentation |
A dataset containing Tabler icon names and their categories.
icons
A data frame with 6,019 rows and 3 variables:
The root category of the icon (e.g., "arrow/arrows", "brand", "device", etc.)
The full icon name (e.g., "arrow-up", "arrow-down", "circle-arrow-up", "circle-arrow-up-filled", etc.)
Logical indicating whether the icon is a filled or not.
Derived from the icons from https://github.com/tabler/tabler-icons
icons[grepl("paw", icons$icon), ]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.