View source: R/layout-condensed.R
| layout_condensed | R Documentation |
Build the HTML structure for the condensed layout. This accepts either a single navbar tag, or a named list with 'top' and 'side' for compatibility with combo-like callers. Returns the full page tag structure (including optional top navbar, page wrapper, body and footer)
layout_condensed(
navbar,
sidebar,
body,
footer,
theme = "light",
color = NULL,
show_theme_button = TRUE
)
navbar |
Navbar component (or list with top/side for combo) |
sidebar |
Sidebar component (not typically used when passing list) |
body |
Body content |
footer |
Footer component |
theme |
Theme name (light/dark) passed for downstream use |
color |
Primary color name |
show_theme_button |
Logical whether to show theme toggles |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.