| menu_dropdown | R Documentation |
Create a nav-item with a dropdown menu using columns like the example
menu_dropdown(text, icon = NULL, href = NULL, items = list())
text |
Title of the dropdown |
icon |
Icon name (optional) |
href |
Link for the dropdown toggle (optional) |
items |
A list of character vectors or tags representing dropdown links; each element can be a character vector of length 2: c(text, href) |
An HTML tag representing the dropdown nav item
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.